# {py:mod}`lastuuid`

```{py:module} lastuuid
```

```{autodoc2-docstring} lastuuid
:parser: myst
:allowtitles:
```

## Package Contents

### Functions

````{list-table}
:class: autosummary longtable
:align: left

* - {py:obj}`uuid7 <lastuuid.lastuuid.uuid7>`
  - ```{autodoc2-docstring} lastuuid.lastuuid.uuid7
    :parser: myst
    :summary:
    ```
* - {py:obj}`uuid7_to_datetime <lastuuid.lastuuid.uuid7_to_datetime>`
  - ```{autodoc2-docstring} lastuuid.lastuuid.uuid7_to_datetime
    :parser: myst
    :summary:
    ```
````

### API

````{py:function} uuid7() -> uuid.UUID
:canonical: lastuuid.lastuuid.uuid7

```{autodoc2-docstring} lastuuid.lastuuid.uuid7
:parser: myst
```
````

````{py:function} uuid7_to_datetime(uuid7: uuid.UUID, tz=timezone.utc) -> datetime.datetime
:canonical: lastuuid.lastuuid.uuid7_to_datetime

```{autodoc2-docstring} lastuuid.lastuuid.uuid7_to_datetime
:parser: myst
```
````
